==> jooq-3.6.2-sources.jar: org/jooq/impl/ScalarSubquery.java <==
/**
 * Copyright (c) 2009-2015, Data Geekery GmbH (http://www.datageekery.com)
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Other licenses:
 * -----------------------------------------------------------------------------
 * Commercial licenses for this work are available. These replace the above
 * ASL 2.0 and offer limited warranties, support, maintenance, and commercial
 * database integrations.
 *
 * For more information, please visit: http://www.jooq.org/licenses
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */

package org.jooq.impl;

import org.jooq.Context;
import org.jooq.DataType;
import org.jooq.Field;
import org.jooq.Select;

/**
 * @author Lukas Eder
 */
class ScalarSubquery<T> extends AbstractField<T> {

    private static final long serialVersionUID = 3463144434073231750L;

    private final Select<?>   query;

    ScalarSubquery(Select<?> query, DataType<T> type) {
        super("select", type);

        this.query = query;
    }

    @Override
    public final Field<T> as(String alias) {
        return new FieldAlias<T>(this, alias);
    }

    @Override
    public final void accept(Context<?> ctx) {
        boolean subquery = ctx.subquery();

        ctx.sql('(')
           .subquery(true)
           .formatIndentStart()
           .formatNewLine()
           .visit(query)
           .formatIndentEnd()
           .formatNewLine()
           .subquery(subquery)
           .sql(')');
    }
}

==> jooq-3.11.9-sources.jar: org/jooq/impl/ScalarSubquery.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Other licenses:
 * -----------------------------------------------------------------------------
 * Commercial licenses for this work are available. These replace the above
 * ASL 2.0 and offer limited warranties, support, maintenance, and commercial
 * database integrations.
 *
 * For more information, please visit: http://www.jooq.org/licenses
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */

package org.jooq.impl;

import org.jooq.Context;
import org.jooq.DataType;
import org.jooq.Field;
import org.jooq.Name;
import org.jooq.Select;

/**
 * @author Lukas Eder
 */
final class ScalarSubquery<T> extends AbstractField<T> {

    private static final long serialVersionUID = 3463144434073231750L;

    private final Select<?>   query;

    ScalarSubquery(Select<?> query, DataType<T> type) {
        super(DSL.name("select"), type);

        this.query = query;
    }

    @Override
    public final Field<T> as(Name alias) {
        return new FieldAlias<T>(this, alias);
    }

    @Override
    public final void accept(Context<?> ctx) {
        ctx.sql('(')
           .subquery(true)
           .formatIndentStart()
           .formatNewLine()
           .visit(query)
           .formatIndentEnd()
           .formatNewLine()
           .subquery(false)
           .sql(')');
    }
}
